# unitorch.models.llama

## LlamaProcessor

::: unitorch.models.llama.LlamaProcessor

## LlamaForClassification

::: unitorch.models.llama.LlamaForClassification

## LlamaForGeneration

::: unitorch.models.llama.LlamaForGeneration
